@@ -8,6 +8,7 @@ from lfs.cart.models import CartItem
 from lfs.cart.models import Cart
 from lfs.payment import utils as payment_utils
 from lfs.shipping import utils as shipping_utils
+from lfs.voucher.models import Voucher
 
 def get_cart_max_delivery_time(request, cart):
     """Returns the delivery time object with the maximal delivery time of all
@@ -27,28 +28,40 @@ def get_cart_max_delivery_time(request, cart):
     return max_delivery_time
 
 # TODO: Remove cart from signature?
-def get_cart_price(request, cart, total=False):
+def get_cart_price(request, cart, total=False, cached=True):
     """Returns price of the given cart.
     """
-    return get_cart_costs(request, cart, total)["price"]
+    return get_cart_costs(request, cart, total, cached)["price"]
 
-def get_cart_costs(request, cart, total=False):
-    """Returns price and tax of the given cart.
+def get_cart_costs(request, cart, total=False, cached=True):
+    """Returns a dictionary with price and tax of the given cart:
+
+        returns {
+            "price" : the cart's price,
+            "tax" : the cart's tax,
+        }
     """
     if cart is None:
         return {"price" : 0, "tax" : 0}
 
     cache_key = "cart-costs-%s-%s" % (total, cart.id)
-    cart_costs = cache.get(cache_key)
+
+    if cached:
+        cart_costs = cache.get(cache_key)
+    else:
+        cart_costs = None
 
     if cart_costs is None:
+
+        items = cart.items()
+
         cart_price = 0
         cart_tax = 0
-        for item in cart.items():
+        for item in items:
             cart_price += item.get_price()
             cart_tax += item.get_tax()
 
-        if total:
+        if len(items) > 0 and total:
             # Shipping
             shipping_method = shipping_utils.get_selected_shipping_method(request)
             shipping_costs = shipping_utils.get_shipping_costs(request, shipping_method)
@@ -61,6 +74,22 @@ def get_cart_costs(request, cart, total=False):
             cart_price += payment_costs["price"]
             cart_tax += payment_costs["tax"]
 
+            # Discounts
+            import lfs.discounts.utils
+            discounts = lfs.discounts.utils.get_valid_discounts(request)
+            for discount in discounts:
+                cart_price = cart_price - discount["price"]
+
+            # Vouchers
+            try:
+                voucher_number = lfs.voucher.utils.get_current_voucher_number(request)
+                voucher = Voucher.objects.get(number=voucher_number)
+            except Voucher.DoesNotExist:
+                pass
+            else:
+                voucher_value = voucher.get_price_gross(cart)
+                cart_price = cart_price - voucher_value
+
         cart_costs = {"price" : cart_price, "tax" : cart_tax}
         cache.set(cache_key, cart_costs)
 
