@@ -3,14 +3,15 @@ from datetime import datetime
 
 # django imports
 from django.core.cache import cache
+from django.core.exceptions import ObjectDoesNotExist
 
 # lfs imports
+import lfs.core.utils
 from lfs.caching.utils import lfs_get_object_or_404
 from lfs.catalog.models import DeliveryTime
 from lfs.catalog.models import Product
 from lfs.catalog.settings import DELIVERY_TIME_UNIT_DAYS
 from lfs.catalog.settings import PRODUCT_WITH_VARIANTS
-from lfs.core.utils import get_default_shop
 from lfs.criteria import utils as criteria_utils
 from lfs.customer import utils as customer_utils
 from lfs.shipping.models import ShippingMethod
@@ -81,6 +82,10 @@ def get_product_delivery_time(request, product_slug, for_cart=False):
             except AttributeError:
                 delivery_time = None
 
+    # TODO: Define default delivery time for the shop
+    if delivery_time is None:
+        delivery_time = DeliveryTime(min=1, max=2, unit=DELIVERY_TIME_UNIT_DAYS)
+
     # Calculate the total delivery time if the product is not on stock.
     if (product.stock_amount <= 0) and (product.order_time):
 
@@ -99,10 +104,6 @@ def get_product_delivery_time(request, product_slug, for_cart=False):
         delivery_time += order_time_left
         delivery_time = delivery_time.as_reasonable_unit()
 
-    # TODO: Define default delivery time for the shop
-    if delivery_time is None:
-        delivery_time = DeliveryTime(min=1, max=2, unit=DELIVERY_TIME_UNIT_DAYS)
-
     delivery_time = delivery_time.round()
     shippings[product_key] = delivery_time
     cache.set(cache_key, shippings)
@@ -165,11 +166,14 @@ def get_selected_shipping_country(request):
     customer = customer_utils.get_customer(request)
     if customer:
         if customer.selected_shipping_address:
-            return customer.selected_shipping_address.country
+            try:
+                return customer.selected_shipping_address.country
+            except ObjectDoesNotExist:
+                pass
         elif customer.selected_country:
             return customer.selected_country
 
-    return get_default_shop().default_country
+    return lfs.core.utils.get_default_shop().get_default_country()
 
 def get_shipping_costs(request, shipping_method):
     """Returns a dictionary with the shipping price and tax for the passed
